@@ -10,7 +10,7 @@ use Fcntl;
 use Lingua::AR::Word;
 
 
-our $VERSION = '2.0';
+our $VERSION = '2.10';
 
 
 sub new{
@@ -26,9 +26,9 @@ sub new{
 }
 
 
-sub value{
+sub value{	# appends a new translation to the arabic word
 
-    my ($this,$arabic_word,$translation)=@_;
+    my ($this,$arabic_word,@new_values)=@_;
 
     my $obj=Lingua::AR::Word->new($arabic_word);
 
@@ -36,14 +36,47 @@ sub value{
     my $word=Lingua::AR::Word::encode($obj->get_word());
 
     my $ref=$this->{$stem};
-    $ref->{$word}=$translation;
+	my $ref_translations;
+
+	if(defined($ref->{$word})){
+		$ref_translations=$ref->{$word};
+	}
+	else{
+		my @translations;
+		$ref_translations=\@translations;
+	}
+
+	push @{$ref_translations},@new_values;
+
+	$ref->{$word}=$ref_translations;
+    $this->{$stem}=$ref;
+
+}
+
+
+sub delete{	# deletes a translation array by deleting a word
+
+    my ($this,$arabic_word,@new_values)=@_;
+
+    my $obj=Lingua::AR::Word->new($arabic_word);
+
+    my $stem=Lingua::AR::Word::encode($obj->get_stem());
+    my $word=Lingua::AR::Word::encode($obj->get_word());
+
+    my $ref=$this->{$stem};
+	my $ref_translations;
+
+	if(defined($ref->{$word})){
+		$ref->{$word}=undef;
+	}
+
     $this->{$stem}=$ref;
 
 }
 
 
 
-sub translate{
+sub translate{	# returns the sorted array of the translations
 
     my ($this,$arabic_word)=@_;
 
@@ -52,8 +85,12 @@ sub translate{
     my $stem=Lingua::AR::Word::encode($obj->get_stem());
     my $word=Lingua::AR::Word::encode($obj->get_word());
 
-    return $this->{$stem}{$word}
-
+	if(defined(@{$this->{$stem}{$word}})){
+    	return sort @{$this->{$stem}{$word}};
+	}
+	else{
+		return undef;
+	}
 }
 
 
@@ -68,7 +105,11 @@ sub export{ # exports the dictionary in text format
         if($stem=~/\w+/){
             my @words=keys(%{$this->{$stem}});
             foreach my $word (@words){
-                $output_string.=$stem."::$word\t$this->{$stem}{$word}\n";
+                if(defined(@{$this->{$stem}{$word}})){
+                    foreach (sort @{$this->{$stem}{$word}}){
+                        $output_string.=$stem."::$word\t$_\n";
+                    }
+                }
             }
         }
     }
@@ -82,6 +123,10 @@ sub export_html{ # exports the dictionary in html form
     my $this=shift;
     my $dir=shift;
 
+
+	if(!defined($dir)){
+		croak "Please specify the HTML folder to export the database to\n";
+	}
     if(!-e $dir){
         mkdir $dir, 0755 or croak "Can't create the directory $dir: $!\n";
     }
@@ -102,10 +147,17 @@ sub export_html{ # exports the dictionary in html form
             open STEM, ">:utf8","$dir/stem-$stem.html" or croak "Cannot create $dir/stem-$stem.html: $!\n";
 
             print STEM &html_header("Stem: $stem","Stem: $stem");
-            print STEM "<small>back to the <a href=\"./index.html\">index page</a></small><ol>";
+            print STEM "<small>back to the <a href=\"./index.html\">index page</a></small>\n\n<ol>\n";
 
-            foreach my $word (@words){
-                print STEM "\t<li>$word = $this->{$stem}{$word}</li>\n";
+            foreach my $word (sort @words){
+                print STEM "\t<li>$word: \n";
+
+				print STEM "\t\t<ul>\n";
+				foreach(@{$this->{$stem}{$word}}){
+					print STEM "\t\t<li>$_</li>\n";
+				}
+
+				print STEM "\t\t</ul>\n</li>\n";
             }
             print STEM "</ol>\n</div>\n</body>\n</html>";
             close STEM;
@@ -142,12 +194,6 @@ return $header;
 
 
 
-
-sub importation{
-
-}
-
-
 1;
 __END__
 
@@ -161,12 +207,18 @@ Lingua::AR::Db - Perl extension for translating Arabic words into another langua
 	use Lingua::AR::Db;
 
 	# this will create a new DB or load an already existent DB
-	my $db=Lingua::AR::Db->new("DATABASE_FILENAME");
+	my $db=Lingua::AR::Db->new($db_name);
 
-	# this will add/overwrite a new translation
-	$db->value("ARABIC_WORD","TRANSLATION");
 
-	print "ARABIC_WORD means $db->translate("ARABIC_WORD")\n";
+	# this will append new translations to the word "مكتب"
+	my $arabic_word="مكتب";
+	$db->value($arabic_word,@translations);
+
+	# let's print out all the translations of the $arabic_word
+	my @array=@{$db->translate($arabic_word)};
+	foreach(@array){
+		print "$arabic_word means $_\n";
+	}
 
 	# this will return every entry of the Database,
 	# formatted as "STEM::WORD\tTRANSLATION"
@@ -186,7 +238,7 @@ This module will take care of the translating an Arabic word into another langua
 You may add new values (translations) to the DB, as well as getting the translation back and exporting into text format or HTML the whole DB.
 
 The DB is structured as a double hash: primary key is the stem of the word, the second key is the word itself.
-The resulting value pointed by these two keys is the translation.
+The resulting value pointed by these two keys is the translations array.
 
 
 If you're interested in a front-end to this module, I'm going to develop one based on Qt widgets.
@@ -199,15 +251,6 @@ I'm going to publish my own Arabic->Italian dictionary on my site @ www.qitty.ne
 Please note that every time you inquire the DB, your arabic word and/or the stem of it, is encoded into ArabTeX.
 This is because Unicode strings can't be keys of the hash at any level.
 
-=head1 TODO
-
-=over
-
-=item importation from flat file
-
-=item management of multiple translation of a word
-
-=back
 
 =head1 SEE ALSO
 
@@ -215,6 +258,20 @@ On my site, you may get additional info about this module.
 You may find more info about ArabTeX at ftp://ftp.informatik.uni-stuttgart.de/pub/arabtex/arabtex.htm
 
 
+=head1 TODO
+
+=over
+
+=item correct use of delete and consequent export[_html]
+
+=item display Arabic characters (instead of|along with) the translitterated ones and sort them according to the Arabic alphabet
+
+=item add accessory methods and variables as needed (translation language,..)
+
+=item export to XML
+
+=back
+
 
 =head1 AUTHOR
 
